@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 use strict;
 use warnings;
@@ -122,9 +122,10 @@ sub	config2perl {
 		$idx++;
 	}
 
-	# thirdly, remove all strings so that if they contain comments
-	# to be left there, this does not include verbatim sections,
-	# which were removed
+	# thirdly, replace all strings with indexed markers
+	# so that their contained comments
+	# to be left intact after the comment substitution which will
+	# be done later on.
 	my @stringsubs;
 	if( $remove_comments_in_strings == 0 ){
 		$idx = 0;
@@ -200,7 +201,7 @@ Config::JSON::Enhanced - JSON-based config with C/Shell-style comments, verbatim
 
 =head1 VERSION
 
-Version 0.03
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -346,14 +347,23 @@ Return value:
 
 =back
 
-Given I<Enhanced JSON> content it removes any comments,
-it replaces all template strings, if any, and then parses
+Given I<Enhanced JSON> content, this sub removes comments
+(as per input parameters),
+replaces all template strings, if any, and then parses
 what remains as standard JSON into a Perl data structure which
 is returned.
 
 JSON content to-be-parsed can be specified with one of the following
 keys in the input parameters hashref (C<$params>):
 
+Comments outside of JSON fields will always be removed.
+
+Comments inside of JSON fields, keys, values, strings etc.
+will not be removed unless input parameter C<remove-comments-in-strings>
+is set to 1.
+
+Comments inside L<Verbatim Sections> will never be removed.
+
 =over 4
 
 =item * C<filename> : content is read from a file with this name.
@@ -467,14 +477,22 @@ For example C</* I am a comment */>, C<// I am a comment to the end of line.>
 =item * C<shell>-style comments can be after C<#> until the end of line.
 For example, C<# I am a comment to the end of line.>
 
+=item * comments with C<custom>, user-specified, opening and
+optional closing tags
+which allows fine-tuning the process of deciding on something being a
+comment.
+
 =back
 
-=item * B<Template variables support> : template variables in the form of C<E<lt>%HOMEDIR%E<gt>>
-will be substituded with their actual values specified by the user during parsing. Note that variable
+=item * B<Template variables support> : template-style
+variables in the form of C<E<lt>%HOMEDIR%E<gt>>
+will be substituded with values specified by the
+user during parsing. Note that variable
 names are case sensitive, they can contain spaces, hyphens etc.,
-for example: C<E<lt>%   abc- 123 -  xyz %E<gt>> (the variable
-name is C<abc- 123 -  xyz>
-(notice the multiple spaces between C<123> and C<xyz>).
+for example: C<E<lt>%   abc- 123 -  xyz   %E<gt>> (the variable
+name is C<abc- 123 -  xyz>, notice
+the multiple spaces between C<123> and C<xyz> and
+also notice the absence of any spaces before C<abc> and after C<xyz>).
 
 The tags for denoting a template variable
 are controled by the 'C<tags>' parameter to the sub L<config2perl>.
@@ -624,6 +642,11 @@ report these cases, see L<SUPPORT>.
 
 Andreas Hadjiprocopis, C<< <bliako at cpan.org> >>
 
+=head1 HUGS
+
+! Almaz !
+
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-config-json-enhanced at rt.cpan.org>, or through
